@@ -32,7 +32,10 @@ Categories
 - 'Q'     : Turbine flow [hydro]
 - 'V'     : Volume [hydro]
 - 'S'     : Spillage [hydro]
+- 'F'     : Line Power Flow
 - 'BAT'   : Battery-specific (charge/discharge/SoC)
+- 'CB'    : Connection Bar Variables
+- 'LT'    : Transmission Lines Variables
 - 'cost'  : Cost components per stage (var, start, deficit)
 - 'CTRL'  : Control variables (U, Y, W)
 
@@ -100,7 +103,7 @@ def print_welcome_banner():
     print(f"{Fore.GREEN}{Style.BRIGHT}NaivePlot: {Fore.CYAN}Reporting CLI For {Fore.MAGENTA}NaivePyDESSEM Simulations{Style.RESET_ALL}\n")
     print(f"{Fore.BLUE}{Style.BRIGHT}Author: {Fore.WHITE}Augusto Mathias Adams {Fore.BLUE}<augusto.adams@ufpr.br>")
     print(f"{Fore.CYAN}{Style.BRIGHT}" + "=" * 70)
-   
+
 
 def prompt(msg: str) -> str:
     """
@@ -185,8 +188,10 @@ def select_variable_columns(df: pd.DataFrame,
         If the category is unrecognized.
     """
 
+    category = category.upper()
+
     if category == "GT":
-        return df.filter(regex=r"^(G_|Ge_|Deficit|Demand).*")
+        return df.filter(regex=r"^(G_|Ge_|Deficit_|Demand_).*")
     elif category == "G":
         return df.filter(regex=r"^G_.*")
     elif category == "Q":
@@ -195,11 +200,17 @@ def select_variable_columns(df: pd.DataFrame,
         return df.filter(regex=r"^S_.*")
     elif category == "V":
         return df.filter(regex=r"^V_.*")
+    elif category == "F":
+        return df.filter(regex=r"^F_.*")
+    elif category == "CB":
+        return df.filter(regex=r"^(\\Theta_|\DemandBar_|DeficitBar_).*")
+    elif category == "LT":
+        return df.filter(regex=r"^(\\Delta_|F_).*")
     elif category == "BAT":
         return df.filter(regex=r"^(D_|C_|E_).*")
-    elif category.lower() == "cost":
+    elif category == "COST":
         return df.filter(regex=r"^Cost_.*")
-    elif category.upper() == "CTRL":
+    elif category == "CTRL":
         return df.filter(regex=r"^(U_|Y_|W_).*")
     else:
         raise ValueError(
@@ -361,6 +372,7 @@ def handle_plot(df: pd.DataFrame,
                 stacked: str = None,
                 title: str = None,
                 ylabel: str = None,
+                xlabel: str = None,
                 out_dir: str = None,
                 out_file: str = None):
     """
@@ -397,6 +409,7 @@ def handle_plot(df: pd.DataFrame,
     plot_style = (plot_style or prompt("Line or bar plot? (line/bar)")).lower()
     title = title or prompt("Enter the title of the plot [optional]")
     ylabel = ylabel or prompt("Enter the y-axis label [optional]")
+    xlabel = xlabel or prompt("Enter the x-axis label [optional]")
     out_dir = out_dir or prompt("Enter the output directory for the figure")
     out_file = out_file or prompt(
         "Enter the output file name (e.g., plot.png)")
@@ -405,6 +418,7 @@ def handle_plot(df: pd.DataFrame,
     t = df["T"] if "T" in df.columns else df.index
     title_use = title if title else ", ".join(categories)
     ylabel_use = ylabel if ylabel else ", ".join(categories)
+    xlabel_use = xlabel if xlabel else ", ".join(categories)
     path = os.path.join(out_dir, out_file)
     if plot_style == "line":
         plot_series(t, series.to_dict(orient="list"),
@@ -413,7 +427,7 @@ def handle_plot(df: pd.DataFrame,
         stacked = (stacked if stacked is not None else prompt(
             "Stacked bars? (y/n)").lower() == "y")
         plot_series_bar(t, series.to_dict(orient="list"), title=title_use,
-                        ylabel=ylabel_use, file=path, stacked=stacked)
+                        ylabel=ylabel_use, xlabel=xlabel_use, file=path, stacked=stacked)
     else:
         print(f"{Fore.RED}Unrecognized plot style.{Style.RESET_ALL}")
     print(f"{Fore.GREEN}✔ Figure saved to:{Style.RESET_ALL} {Fore.CYAN}{path}{Style.RESET_ALL}")
@@ -476,27 +490,28 @@ def main():
                         help="Use stacked bars (bar plots only)")
     parser.add_argument("--title", help="Plot title or LaTeX caption")
     parser.add_argument("--ylabel", help="Y-axis label (plots)")
+    parser.add_argument("--xlabel", help="X-axis label (plots)")
     parser.add_argument("--out-dir", help="Output directory")
     parser.add_argument(
         "--out-file", help="Output file name (plot image or .tex)")
     parser.add_argument("--label", help="LaTeX label (tables)")
     args = parser.parse_args()
     df = load_dataframe(args.input_file)
-    print("Available categories: G (Generation), Q (Turbine flow), S (Spillage), V (Volume), cost, CTRL (U/Y/W), BAT")
+    print("Available categories: G (Generation), Q (Turbine flow), S (Spillage), V (Volume), CB (Connection Bars), \n LT (Transmission Lines), COST, CTRL (U/Y/W), BAT")
     mode = args.mode or prompt(
         "Generate table, plot, or CTRL matrix? (table/plot/ctrl)").lower()
     if mode == "ctrl":
         handle_control_variables(
             df, out_dir=args.out_dir, out_file=args.out_file, caption=args.title, label=args.label)
         return
-    categories = [c.upper() if c.lower() != "cost" else "cost" for c in (
-        args.category or prompt("Enter category(ies) separated by spaces (e.g., G S V):").split())]
+    categories = [c.upper() for c in (
+        args.category or prompt("Enter category(ies) separated by spaces (e.g., G S V F):").split())]
     if mode == "table":
         handle_table(df, categories, out_dir=args.out_dir,
                      out_file=args.out_file, caption=args.title, label=args.label)
     elif mode == "plot":
         handle_plot(df, categories, plot_style=args.plot_style, stacked=args.stacked,
-                    title=args.title, ylabel=args.ylabel, out_dir=args.out_dir, out_file=args.out_file)
+                    title=args.title, ylabel=args.ylabel, xlabel=args.xlabel, out_dir=args.out_dir, out_file=args.out_file)
     else:
         print("Unrecognized mode.")
 
